CPI and PPP deflators.
deflators.RdA dataset containing the Consumer Price Index (CPI) and Purchasing Power Parity (PPP) deflators that can be used to directly compare absolute monetary values across different LIS, LWS and LCS datasets.

deflators.RdA dataset containing the Consumer Price Index (CPI) and Purchasing Power Parity (PPP) deflators that can be used to directly compare absolute monetary values across different LIS, LWS and LCS datasets.