Value Labels for Country-Specific Variables in LIS, LWS, LCS Datasets
value_label_c_data.RdA data frame containing the categorized values of country-specific variables in the LIS, LWS, LCS datasets, organized by country and year.
A data frame containing the categorized values of country-specific variables in the LIS and LWS datasets, organized by country and year.