Validate the Weight Variable Input
check_input_in_weight_argument.RdThis function checks the validity of the weight variable provided by the user, issuing a helpful message if the variable name does not end with "wgt", as expected by LIS conventions.